@@ -1,6 +1,6 @@
 plot.SimGR <- function(x, ...) {
 
-  if (! any(class(x) %in% "SimGR")) {
+  if (!inherits(x, "SimGR")) {
     stop("Non convenient data for x argument. Must be of class \"SimGR\"")
   }
 
